#ifndef AUDIOLAYERWIDGET_H
#define AUDIOLAYERWIDGET_H

#include <QByteArray>

#include <QLabel>
#include <QPushButton>
#include <QSlider>
#include <QTimer>
#include <QTime>
#include <QTimeEdit>
#include <QGroupBox>
#include <QCheckBox>

#include "SFML/Audio.hpp"
#include "SFML/System.hpp"

#include "defines.h"

class AudioLayerWidget : public QGroupBox
{
    Q_OBJECT
    
public:

    explicit AudioLayerWidget(QWidget *parent = 0, QString name = "Layer");
    ~AudioLayerWidget();

    void loadMedia(QString file);
    void play();
    void stop();
    void pause();
    void setVol(qreal vol);
    void resume();
//    void updateWatchDMX(bool b);

public slots:

    void toggleSuspendResume();
    void volumeChanged(int vol);

private:
    QPushButton *m_suspendResumeButton;

    QLabel *m_statusLabel;
    QLabel * m_statusValue;

    QLabel *m_volumeLabel;
    QSlider *m_volumeSlider;

    QLabel * m_progressLabel;
    QSlider *m_progressSlider;

    QLabel *m_progressTimeLabel;
    QTimeEdit *m_progressTime;

    QLabel *m_totalTimeLabel;
    QTimeEdit *m_totalTimeValue;

    QLabel *m_fileLabel;
    QLabel *m_fileValue;

    QLabel * m_folderLabel;
    QLabel * m_folderValue;

    QCheckBox *m_receiveDMX;
    QTimer *m_watchDMX;

//    QTime *m_progressCounter;
//    quint64 m_progressMs;

    QString m_currentMedia;

    bool m_running;

    sf::Music m_music;

private slots:
//    void notified();
    void fileLoaded(QString file);
    void durationChanged(qint64 dur);
    void watchDMXExpired();
};



#endif // AUDIOLAYERWIDGET_H
